@@ -1,22 +1,19 @@
-# $Id: ExecuteJobs.pm,v 1.19 2005/12/26 13:57:47 joern Exp $
+# $Id: ExecuteJobs.pm,v 1.3 2002/09/22 09:36:07 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::GUI::ExecuteJobs;
-use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
+
 
 use base Video::DVDRip::GUI::Base;
 
 use Video::DVDRip::GUI::Pipe;
 
-use Video::DVDRip::Job::ProbeTitleCount;
 use Video::DVDRip::Job::Probe;
 use Video::DVDRip::Job::Rip;
 use Video::DVDRip::Job::GrabPreviewFrame;
@@ -26,16 +23,8 @@ use Video::DVDRip::Job::Split;
 use Video::DVDRip::Job::Mplex;
 use Video::DVDRip::Job::TranscodeAudio;
 use Video::DVDRip::Job::MergeAudio;
-use Video::DVDRip::Job::CreateCDImage;
-use Video::DVDRip::Job::BurnCD;
-use Video::DVDRip::Job::GrabSubtitleImages;
-use Video::DVDRip::Job::ExtractPS1;
-use Video::DVDRip::Job::CreateVobsub;
-use Video::DVDRip::Job::CountFramesInFile;
-use Video::DVDRip::Job::CreateWav;
 
 use strict;
-use Carp;
 
 # list ref of jobs, to bew executed in the specified order
 sub jobs			{ shift->{jobs}				}
@@ -69,13 +58,13 @@ sub new {
 	my  ($cb_finished, $reuse_progress) =
 	@par{'cb_finished','reuse_progress'};
 
-	my $self = $class->SUPER::new(@_);
-
-	$self->{jobs}		= [];
-	$self->{cb_finished}	= $cb_finished;
-	$self->{reuse_progress}	= $reuse_progress;
-
-	return $self;
+	my $self = {
+		jobs		=> [],
+		cb_finished 	=> $cb_finished,
+		reuse_progress	=> $reuse_progress,
+	};
+	
+	return bless $self, $class;
 }
 
 sub add_job {
@@ -90,56 +79,15 @@ sub add_job {
 
 sub execute_jobs {
 	my $self = shift;
-	my %par = @_;
-	my  ($no_diskspace_check, $max_diskspace_needed) =
-	@par{'no_diskspace_check','max_diskspace_needed'};
-
+	
 	my $jobs = $self->jobs;
 
 	my $job_started;
-	my $title = $self->get_context->get_object("title");
-
-	if ( $title and not $no_diskspace_check ) {
-		$max_diskspace_needed ||=
-			Video::DVDRip::Job->get_max_disk_usage (
-				jobs => $jobs,
-			);
-
-		my $free = $title->project->get_free_diskspace ( kb => 1 );
-
-		$max_diskspace_needed = int ($max_diskspace_needed/1024);
-		$free = int($free/1024);
-
-		$self->log (__x("This task needs about {needed} MB, {free} MB are free.", needed => $max_diskspace_needed, free => $free));
-
-		my $max_diskspace_needed_plus_spare = $max_diskspace_needed + 100;
-		if ( $max_diskspace_needed_plus_spare > $free ) {
-			$self->confirm_window (
-			    message =>
-				__x("Warning: diskspace is low. This task needs\nabout {needed} MB, but only {free} MB are available.\nDo you want to continue anyway?", needed => $max_diskspace_needed_plus_spare, free => $free),
-			    yes_callback => sub {
-			    	$self->execute_jobs (
-				    no_diskspace_check => 1,
-				);
-			    },
-			    yes_label => __"Yes",
-			    no_label => __"No",
-			    no_callback => sub {
-			    	$self->set_cancelled(1);
-				$self->finished;
-			    },
-			    omit_cancel => 1,
-			);
-			return 1;
-		}
-	}
-
-	my $progress = $self->progress;
 
 	foreach my $job ( @{$jobs} ) {
 		next if $job->state ne 'waiting';
 		next if not $job->dependency_ok;
-
+		
 		$job_started = 1;
 		$job->init if $job->can('init');
 		$job->set_cb_next_job (
@@ -152,8 +100,8 @@ sub execute_jobs {
 			sub { $self->update_progress(@_) }
 		);
 
-		if ( not $progress->is_active ) {
-			$progress->open (
+		if ( not $self->comp('progress')->is_active ) {
+			$self->comp('progress')->open (
 				max_value => $job->progress_max,
 				label     => $job->calc_progress,
 				cb_cancel => sub {
@@ -169,7 +117,7 @@ sub execute_jobs {
 
 		if ( $@ ) {
 			$self->long_message_window (
-				message => $@,
+				message => $self->stripped_exception
 			);
 			$job_started = 0;
 			next;
@@ -200,10 +148,10 @@ sub next_job {
 		);
 	}
 
-	$self->progress->close
-		unless $self->reuse_progress;
+	$self->comp('progress')->close
+		if not $self->reuse_progress;
 	
-	$self->execute_jobs ( no_diskspace_check => 1);
+	$self->execute_jobs;
 	
 	1;
 }
@@ -211,8 +159,8 @@ sub next_job {
 sub finished {
 	my $self = shift;
 
-	my $progress = $self->progress;
-	$progress->close if $progress->is_active;
+	$self->comp('progress')->close
+		if $self->comp('progress')->is_active;
 
 	my $cb_finished = $self->cb_finished;
 	&$cb_finished() if $cb_finished;
@@ -227,8 +175,8 @@ sub job_aborted {
 
 	$self->set_errors_occured(1);
 
-	$self->progress->close
-		unless $self->reuse_progress;
+	$self->comp('progress')->close
+		if not $self->reuse_progress;
 
 	if ( $job->cancelled ) {
 		$self->set_cancelled(1);
@@ -241,18 +189,14 @@ sub job_aborted {
 	} else {
 		$self->long_message_window (
 			message =>
-				__x("Job '{job}' failed.\n\nExecuted command: {command}\n\nLast output was:\n\n", job => $job->info, command => $job->command ).
+				"Job '".$job->info."' failed.\n\n".
+				"Executed command: ".$job->command."\n\n".
+				"Last output was:\n\n".
 				$job->pipe->output
 		);
-		$self->log (
-			__"You should analyze the last output of this job to see what's going wrong here:"
-		);
-		my $output = $job->pipe->output;
-		$output =~ s/^\s+//;
-		$output =~ s/\s+$//;
-		$self->log (__"---- job output start ----")."\n\n\n";
-		$self->log (__"---- job output end ----");
 	}
+	# try hard
+	$self->execute_jobs;
 
 	1;
 }
@@ -263,13 +207,9 @@ sub update_progress {
 	my ($job) = @par{'job'};
 
 	return 1 if $self->cancelled;
-	
-	my $cnt = $job->progress_cnt;
-	my $max = $job->progress_max;
-	$max ||= 1;
 
-	$self->progress->update (
-		value => $cnt/$max,
+	$self->comp('progress')->update (
+		value => $job->progress_cnt,
 		label => $job->progress,
 	);
 	
