@@ -1,16 +1,13 @@
-# $Id: Rip.pm,v 1.12 2005/12/26 13:57:47 joern Exp $
+# $Id: Rip.pm,v 1.1 2002/09/01 13:57:52 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This program is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::Rip;
-use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Job;
 
@@ -27,10 +24,9 @@ sub type {
 sub info {
 	my $self = shift;
 
-	my $info = __"Ripping";
-	$info .= " - ".__x("title #{title}", title => $self->title->nr);
+	my $info = "Ripping - title #".$self->title->nr;
 
-	$info .= ", ".__x("chapter {chapter}", chapter => $self->chapter) if $self->chapter;
+	$info .= ", chapter ".$self->chapter if $self->chapter;
 
 	return $info;
 }
@@ -38,38 +34,14 @@ sub info {
 sub init {
 	my $self = shift;
 	
-	my $title   = $self->title;
-	my $chapter = $self->chapter;
+	my $title = $self->title;
 	
 	$self->set_progress_show_fps ( 1 );
+	$self->set_progress_max ( $title->frames );
 	
-	if ( not $chapter or $self->title->tc_use_chapter_mode eq 'all' ) {
-		$self->set_progress_max ( $title->frames );
-
-	} elsif ( $chapter and $self->title->chapter_frames->{$chapter} ) {
-		$self->set_progress_max (
-			$self->title->chapter_frames->{$chapter}
-		);
-
-	} else {
-		$self->set_progress_show_percent( 0 );
-		$self->set_progress_max ( 0 );
-		
-	}
-
 	1;
 }
 
-sub get_diskspace_needed {
-	my $self = shift; $self->trace_in;
-
-	return 0;
-}
-
-sub get_diskspace_freed {
-	return 0;
-}
-
 sub command {
 	my $self = shift;
 
@@ -102,20 +74,15 @@ sub commit {
 	
 	my $title = $self->title;
 	
-	my $count = 0;
-
-	$count = 1 if $self->chapter and
-		      $self->chapter != $title->get_first_chapter;
-
 	$title->analyze_scan_output (
-		output => $self->pipe->output,
-		count  => $count,
+		output => $self->pipe->output
 	);
 	
-	my $audio_tracks  = $title->audio_tracks;
+	my $tc_audio_tracks = $title->tc_audio_tracks;
+	my $audio_channel   = $title->audio_channel;
 	
-	$_->set_tc_target_track(-1) for @{$audio_tracks};
-	$title->audio_track->set_tc_target_track(0);
+	$_->set_tc_target_track(-1) for @{$tc_audio_tracks};
+	$tc_audio_tracks->[$audio_channel]->set_tc_target_track(0);
 
 	$title->set_actual_chapter($self->chapter);
 
@@ -147,7 +114,7 @@ sub commit {
 				"WARNING: it seems that transcode ripping stopped short.\n".
 				"The movie has $title_frames frames, but only $job_frames\n".
 				"were ripped. This is most likely a problem with your\n".
-				"transcode/libdvdread installation, resp. a problem with\n".
+				"transcode/libdvdread/libdvdcss installation, resp. with\n".
 				"this specific DVD."
 			);
 		}
