@@ -1,4 +1,4 @@
-# $Id: Probe.pm,v 1.12 2002/03/29 16:18:54 joern Exp $
+# $Id: Probe.pm,v 1.13 2002/09/01 13:55:49 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -11,6 +11,8 @@ package Video::DVDRip::Probe;
 
 use base Video::DVDRip::Base;
 
+use Video::DVDRip::ProbeAudio;
+
 use Carp;
 use strict;
 
@@ -49,7 +51,7 @@ sub set_viewing_angles		{ shift->{viewing_angles}	= $_[1]	}
 sub analyze {
 	my $class = shift;
 	my %par = @_;
-	my ($probe_output) = @par{'probe_output'};
+	my ($probe_output, $title) = @par{'probe_output','title'};
 
 	my ($width, $height, $aspect_ratio, $video_mode, $letterboxed);
 	my ($frames, $runtime, $frame_rate, $audio_size, $chapters, $angles);
@@ -101,6 +103,30 @@ sub analyze {
 		++$i;
 	}
 
+	my @audio_track_objects;
+	my @tc_audio_track_objects;
+	$i = 0;
+	foreach my $audio ( @audio_tracks ) {
+		push @audio_track_objects, Video::DVDRip::ProbeAudio->new (
+			type		=> $audio->{type},
+			lang		=> $audio->{lang},
+			channels	=> $audio->{channels},
+			sample_rate	=> $audio->{sample_rate},
+		);
+		push @tc_audio_track_objects, Video::DVDRip::Audio->new (
+			tc_nr 		=> $i,
+			tc_target_track	=> ($i==0 ? 0 : -1),
+			tc_audio_codec	=> "mp3",
+			tc_bitrate	=> 128,
+			tc_mp3_quality	=> 0,
+		);
+		++$i;
+	}
+
+	$title->set_tc_audio_tracks ( \@tc_audio_track_objects );
+
+	$title->set_audio_channel(@audio_tracks? 0 : -1);
+
 	my $self = {
 		probe_output 	=> $probe_output,
 		width	   	=> $width,
@@ -114,7 +140,7 @@ sub analyze {
 		chapters	=> $chapters,
 		audio_size      => $audio_size,
 		bitrates	=> \%bitrates,
-		audio_tracks    => \@audio_tracks,
+		audio_tracks    => \@audio_track_objects,
 		viewing_angles  => $angles,
 	};
 	
@@ -124,7 +150,8 @@ sub analyze {
 sub analyze_audio {
 	my $self = shift;
 	my %par = @_;
-	my ($probe_output) = @par{'probe_output'};
+	my  ($probe_output, $title) =
+	@par{'probe_output','title'};
 	
 	$self->set_audio_probe_output ( $probe_output );
 	
@@ -134,10 +161,11 @@ sub analyze_audio {
 	for ( my $i=0; $i < @lines; ++$i ) {
 		if ( $lines[$i] =~ /audio\s+track:\s+-a\s+(\d+).*?-n\s+([x0-9]+)/ ) {
 			$nr = $1;
-			$self->audio_tracks->[$nr]->{tc_option_n} = $2;
+			next if not defined $self->audio_tracks->[$nr];
+			$title->tc_audio_tracks->[$nr]->set_tc_option_n ($2);
 			++$i;
 			$lines[$i] =~ /bitrate\s*=(\d+)/;
-			$self->audio_tracks->[$nr]->{bitrate} = $1;
+			$self->audio_tracks->[$nr]->set_bitrate($1);
 		}
 	}
 	
